==> com.liferay.commerce.api-2.0.0-sources.jar: com/liferay/commerce/constants/CommercePortletKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.commerce.constants;

/**
 * @author Marco Leo
 * @author Alessio Antonio Rendina
 */
public class CommercePortletKeys {

	public static final String COMMERCE_ADDRESS_CONTENT =
		"com_liferay_commerce_address_content_web_internal_portlet_" +
			"CommerceAddressContentPortlet";

	public static final String COMMERCE_CART_CONTENT =
		"com_liferay_commerce_cart_content_web_internal_portlet_" +
			"CommerceCartContentPortlet";

	public static final String COMMERCE_CART_CONTENT_MINI =
		"com_liferay_commerce_cart_content_web_internal_portlet_" +
			"CommerceCartContentMiniPortlet";

	public static final String COMMERCE_CART_CONTENT_TOTAL =
		"com_liferay_commerce_cart_content_web_internal_portlet_" +
			"CommerceCartContentTotalPortlet";

	public static final String COMMERCE_CHECKOUT =
		"com_liferay_commerce_checkout_web_internal_portlet_" +
			"CommerceCheckoutPortlet";

	public static final String COMMERCE_ORDER =
		"com_liferay_commerce_order_web_internal_portlet_CommerceOrderPortlet";

	public static final String COMMERCE_ORDER_CONTENT =
		"com_liferay_commerce_order_content_web_internal_portlet_" +
			"CommerceOrderContentPortlet";

	public static final String COMMERCE_ORGANIZATION_OPEN_ORDER =
		"com_liferay_commerce_organization_order_web_internal_portlet_" +
			"CommerceOrganizationOpenOrderPortlet";

	public static final String COMMERCE_ORGANIZATION_ORDER =
		"com_liferay_commerce_organization_order_web_internal_portlet_" +
			"CommerceOrganizationOrderPortlet";

	public static final String COMMERCE_SHIPMENT =
		"com_liferay_commerce_shipment_web_internal_portlet_" +
			"CommerceShipmentPortlet";

	public static final String COMMERCE_SHIPMENT_CONTENT =
		"com_liferay_commerce_shipment_content_web_internal_portlet_" +
			"CommerceShipmentContentPortlet";

}

==> com.liferay.commerce.api-4.0.0-sources.jar: com/liferay/commerce/constants/CommercePortletKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.commerce.constants;

/**
 * @author Marco Leo
 * @author Alessio Antonio Rendina
 */
public class CommercePortletKeys {

	public static final String COMMERCE_ADDRESS_CONTENT =
		"com_liferay_commerce_address_content_web_internal_portlet_" +
			"CommerceAddressContentPortlet";

	public static final String COMMERCE_CART_CONTENT =
		"com_liferay_commerce_cart_content_web_internal_portlet_" +
			"CommerceCartContentPortlet";

	public static final String COMMERCE_CART_CONTENT_MINI =
		"com_liferay_commerce_cart_content_web_internal_portlet_" +
			"CommerceCartContentMiniPortlet";

	public static final String COMMERCE_CART_CONTENT_TOTAL =
		"com_liferay_commerce_cart_content_web_internal_portlet_" +
			"CommerceCartContentTotalPortlet";

	public static final String COMMERCE_CHECKOUT =
		"com_liferay_commerce_checkout_web_internal_portlet_" +
			"CommerceCheckoutPortlet";

	public static final String COMMERCE_OPEN_ORDER_CONTENT =
		"com_liferay_commerce_order_content_web_internal_portlet_" +
			"CommerceOpenOrderContentPortlet";

	public static final String COMMERCE_ORDER =
		"com_liferay_commerce_order_web_internal_portlet_CommerceOrderPortlet";

	public static final String COMMERCE_ORDER_CONTENT =
		"com_liferay_commerce_order_content_web_internal_portlet_" +
			"CommerceOrderContentPortlet";

	public static final String COMMERCE_SHIPMENT =
		"com_liferay_commerce_shipment_web_internal_portlet_" +
			"CommerceShipmentPortlet";

	public static final String COMMERCE_SHIPMENT_CONTENT =
		"com_liferay_commerce_shipment_content_web_internal_portlet_" +
			"CommerceShipmentContentPortlet";

}
